﻿// Created By Lee Dyche for http://www.tecsploit.com
// Send any queries to lee@tecsploit.com
//
//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.

//You should have received a copy of the GNU General Public License
//along with this program.  If not, see <http://www.gnu.org/licenses/>.


using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Reflection;
using System.IO;

namespace ResourceExtractor
{
    public partial class Form1 : Form
    {

        private Assembly SelectedAssembly;

        public Form1()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            try
            {
                if (String.IsNullOrEmpty(extractDirectoryBox.Text))
                {
                    MessageBox.Show("You must select an export directory");
                    return;
                }

                if (String.IsNullOrEmpty(this.assemblyLocationBox.Text))
                {
                    MessageBox.Show("You must select a target assembly");
                    return;
                }

                string[] resources = SelectedAssembly.GetManifestResourceNames();

                foreach (string s in resources)
                {
                    Log("Attempting to extract: " + s);
                    Stream stream = SelectedAssembly.GetManifestResourceStream(s);
                    FileStream fs = new FileStream(extractDirectoryBox.Text + @"\" + s, FileMode.CreateNew);
                    BinaryReader Reader = new BinaryReader(stream);
                    BinaryWriter Writer = new BinaryWriter(fs);

                    Writer.Write(Reader.ReadBytes((int)stream.Length));

                    Reader.Close();
                    Writer.Close();
                    stream.Close();
                    Log("Resource extracted");
                }

                Log("Extraction complete!");

            }
            catch (Exception exp) {
                Log("Error extracting..." +exp.ToString());
            }
        }

        private void chooseDirectoryButton_Click(object sender, EventArgs e)
        {

            OpenFileDialog di = new OpenFileDialog();
            DialogResult r = di.ShowDialog(this);

            if (r == DialogResult.OK)
            {
                assemblyLocationBox.Text = di.FileName;

                Log("Attempting to load assembly: " + assemblyLocationBox.Text);
                try
                {
                    SelectedAssembly = Assembly.LoadFrom(assemblyLocationBox.Text);

                    string[] resources = SelectedAssembly.GetManifestResourceNames();

                    if (resources != null)
                    {
                        Log("Assembly Loaded, following resources found: ");

                        foreach (string name in resources)
                        {
                            Log(name);
                        }
                    }
                    else
                    {
                        Log("Assembly Loaded, no resources found: ");
                    }


                }
                catch (Exception exp)
                {
                    Log("Error Loading Assembly: " + exp.ToString());
                }
            }
        }

        private void exportDirectoryButton_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog di = new FolderBrowserDialog();
            DialogResult r = di.ShowDialog(this);

            if (r == DialogResult.OK)
            {
                extractDirectoryBox.Text = di.SelectedPath;
            }
        }

        private void Log(string message) {
            outputBox.Text = outputBox.Text + Environment.NewLine + message ;
        }

    }
}
